==> blobAndConquer-0.1-1.tar.gz: BlobAndConquer/src/battle.h <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void drawTitle();
extern void drawControlPanel();
extern void drawWidgets();
extern void loadWidgets(char *filename);
extern void loadGameLocaleData(char *filename, bool append);
extern void drawUnits();
extern void saveGameData(int slot, bool autoSaving);
extern void saveGame();
extern void doBullets();
extern void doItems();
extern void centerOnUnit(Unit *unit);
extern void setStatusIndicator();
extern void doLineOfSight(Unit *unit);
extern void blobCheckEnemyMovement();
extern void drawContextItems();
extern void doDebriefing();
extern void updateFire();
extern void drawMap();
extern void doPlayerTurn();
extern void doEnemyTurn();
extern void resetControlsForUnit(Unit *unit);
extern void doDecoration();
extern void drawDecoration();
extern void doParticles();
extern void drawMouseVector();
extern bool itemExplosions();
extern void doDebriefing();
extern void triggerExplosion(float mapX, float mapY, float mapZ, int size);
extern bool allObjectivesComplete();
extern bool allEnemyUnitsDead();
extern void loadAllBattleResources();
extern void loadMapAudio();
extern void doPreBattlePlayerSetup();
extern void doPlayer();
extern void doBullets();
extern void drawInfoPanel();
extern void drawSelectedUnit();
extern void doEnemies();
extern void doBlobs();
extern void doTriggers();
extern void doFeatures();
extern void showMissionStatusPanel(bool missionFinished);
extern void renderBSP();
extern void drawSkyDome(Vector position, int size, Texture *texture);
extern void resetPlayer();
extern void preBattleSetup();
extern void resetEnemyThinkTimes();
extern void doWeather();
extern void doElements();
extern void doInGameOptions();
extern int doGameOver();
extern void showMessageDialog(char *message, char *buttonLabel);
extern void spawnRandomEnemy();
extern void checkEntityToOthers(Entity *entity);
extern bool checkEntityToWorld(Entity *entity);

extern Audio *audio;
extern BSP *bsp;
extern BoundingBoxManager *bbManager;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern Mission *mission;
extern ModelManager *modelManager;
extern Mouse *mouse;
extern ParticleManager *particleManager;
extern TextureManager *textureManager;
extern TextureSpecManager *textureSpecManager;
extern Trace *tracer;
extern UIManager *uiManager;
extern Unit *player;

==> blobAndConquer-0.2-1.tar.gz: BlobAndConquer/src/battle.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "headers.h"

extern void drawTitle();
extern void drawControlPanel();
extern void drawWidgets();
extern void loadWidgets(char *filename);
extern void loadGameLocaleData(char *filename, bool append);
extern void drawUnits();
extern void saveGameData(int slot, bool autoSaving);
extern void saveGame();
extern void doBullets();
extern void doItems();
extern void centerOnUnit(Unit *unit);
extern void setStatusIndicator();
extern void doLineOfSight(Unit *unit);
extern void blobCheckEnemyMovement();
extern void drawContextItems();
extern void doDebriefing();
extern void updateFire();
extern void drawMap();
extern void doPlayerTurn();
extern void doEnemyTurn();
extern void resetControlsForUnit(Unit *unit);
extern void doDecoration();
extern void drawDecoration();
extern void doParticles();
extern void doEmitters();
extern void drawMouseVector();
extern bool itemExplosions();
extern void doDebriefing();
extern void triggerExplosion(float mapX, float mapY, float mapZ, int size);
extern bool allObjectivesComplete();
extern bool allEnemyUnitsDead();
extern void loadAllBattleResources();
extern void loadMapAudio();
extern void doPreBattlePlayerSetup();
extern void doPlayer();
extern void doBullets();
extern void drawInfoPanel();
extern void drawSelectedUnit();
extern void doEnemies();
extern void doBlobs();
extern void doTriggers();
extern void doFeatures();
extern void showMissionStatusPanel(bool missionFinished);
extern void renderBSP();
extern void drawSkyDome(Vector position, int size, Texture *texture);
extern void resetPlayer();
extern void resetEnemyThinkTimes();
extern void doWeather();
extern void doStructures();
extern void doInGameOptions();
extern int doGameOver();
extern void showMessageDialog(char *message, char *buttonLabel);
extern void spawnRandomEnemy();
extern void checkEntityToOthers(Entity *entity);
extern bool checkEntityToWorld(Entity *entity);
extern void doInGameCutscene();
extern void drawParticles();
extern void drawBSP(bool drawBlended);
extern void drawLaserSight(Unit *unit);
extern void generateShadow();
extern void drawShadow();
extern bool isOkayToSpawnEnemies();

extern Audio *audio;
extern BSP *bsp;
extern BoundingBoxManager *bbManager;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern Mission *mission;
extern ModelManager *modelManager;
extern Mouse *mouse;
extern ParticleManager *particleManager;
extern TextureManager *textureManager;
extern TextureSpecManager *textureSpecManager;
extern Trace *tracer;
extern UIManager *uiManager;
extern Unit *player;
